@@ -15,7 +15,7 @@ use EPublisher::Utils::PPI qw(extract_pod_from_code);
 
 our @ISA = qw( EPublisher::Source::Base );
 
-our $VERSION = 0.17;
+our $VERSION = 0.18;
 
 # implementing the interface to EPublisher::Source::Base
 sub load_source{
@@ -127,12 +127,15 @@ sub load_source{
                 1;
             } or do{ $self->publisher->debug( $@ ); next; };
 
-            next if !$pod_src;
-            next if $pod_src =~ m!{ ( \s+ "message" \s : \s+ )? }!xms;
+            if (!$pod_src) {
+                $self->publisher->debug( "103: empty pod handle" );
+                next;
+            }
 
             # metacpan always provides utf-8 encoded data, so we have to decode it
             # otherwise the target plugins may produce garbage
             $pod_src = decode( 'utf-8', $pod_src );
+
         }
         else {
             # if there is no head we consider this POD unvalid
@@ -152,7 +155,7 @@ sub load_source{
         push @pod, $info;
         $self->publisher->debug( "103: passed info " . Dumper $info );
     }
-    
+
     # voilà
     return @pod;
 }
@@ -169,7 +172,7 @@ EPublisher::Source::Plugin::MetaCPAN - Get POD from distributions via MetaCPAN
 
 =head1 VERSION
 
-version 0.17
+version 0.18
 
 =head1 SYNOPSIS
 
